@@ -372,8 +372,13 @@ setup_fields (ETableConfig *config)
 
 	if (config->temp_state) {
 		for (i = 0; i < config->temp_state->col_count; i++) {
-			e_table_subset_variable_add (config->shown_model, config->temp_state->columns[i]);
-			e_table_without_hide (config->available_model, (void *) config->temp_state->columns[i]);
+			gint j, idx;
+			for (j = 0, idx = 0; j < config->temp_state->columns[i]; j++)
+				if (!config->source_spec->columns[j]->disabled)
+					idx++;
+
+			e_table_subset_variable_add (config->shown_model, idx);
+			e_table_without_hide (config->available_model, GINT_TO_POINTER(idx));
 		}
 	}
 }
@@ -517,10 +522,14 @@ create_global_store (ETableConfig *config)
 
 	global_store = e_table_memory_store_new (store_columns);
 	for (i = 0; config->source_spec->columns[i]; i++) {
-		char *text = g_strdup (dgettext (config->domain,
-								  config->source_spec->columns[i]->title));
 
-		e_table_memory_store_insert_adopt (E_TABLE_MEMORY_STORE (global_store), i, NULL, text);
+		char *text;
+
+		if (config->source_spec->columns[i]->disabled)
+			continue;
+
+		text = g_strdup (dgettext (config->domain, config->source_spec->columns[i]->title));
+		e_table_memory_store_insert_adopt (E_TABLE_MEMORY_STORE (global_store), -1, NULL, text);
 	}
 }
 
